@@ -52,6 +52,9 @@ class WFAQuantizationComparator(FiniteAutomataComparator):
             visitedPairs.add(pair)
         return None
 
+    def equivalent_output(self, observation1, observation2) -> bool:
+        return pdfa_utils.are_in_same_partition(observation1, observation2, self.partitions)
+
     def _pair_equivalent_by_name(self, states_pair1, states_pair2):
         return states_pair1[0].name == states_pair2[0].name and states_pair1[1].name == states_pair2[1].name
 
